#!/bin/sh
# Generic installer, as requested
# Let's set some vars
set -x
VERSION="1.3.2"
UNAME="MountFile"
NAME="$(echo ${UNAME}|tr [A-Z] [a-z])"
CMDNAME=$(basename $0)

## Do we have KDE?
if ! $(kde-config)
  then xmessage "I can't locate KDE on this system.
Make sure kde-config is in your \$PATH"
  exit 1
fi

## KDE's Prefix
PREFIX="$(kde-config --prefix)"

MSG="kdialog --icon ${PREFIX}/share/pixmaps/ark-16.xpm --caption \"$UNAME installer\" --msgbox"
ASK="kdialog --icon ${PREFIX}/share/pixmaps/ark-16.xpm --caption \"$UNAME installer\" --yesno"
ERROR="kdialog --icon ${PREFIX}/share/pixmaps/ark-16.xpm --caption \"$UNAME installer\" --error"
export TEMPFILE="/tmp/temp.$$" 
# End (could be done better?)

# Find the directory with the script in it
if [ -d "${HOME}/${NAME}-${VERSION}" ]
	then cd ${HOME}/${NAME}-${VERSION}
elif [ -d "$(dirname $0)" ]
	then cd $(dirname $0)
	else $ERROR "I can't find the directory with the script in it\nPlease select it now" # Should never happen, but...
	kdialog --icon /usr/share/pixmaps/ark-16.xpm --caption "$UNAME installer" --getexistingdirectory ${HOME} || exit
fi

# Make a .desktop file
desktop_file()
{
cat << EOD
[Desktop Entry]
Comment=Mounts a Filesystem image (iso,img)
Comment[en_GB]=Mounts a Filesystem image (iso,img)
Encoding=UTF-8
Exec=${BINDIR}/mountfile
GenericName=Mount a File
GenericName[en_GB]=Mount a File
Icon=cdwriter_unmount
MimeType=
Name=Mount File
Name[en_GB]=Mount File
Path=
StartupNotify=true
Terminal=false
TerminalOptions=
Type=Application
X-DCOP-ServiceType=
X-KDE-SubstituteUID=false
X-KDE-Username=
EOD
}

# Install system-wide
system_install()
{
export PREFIX="$(kde-config --prefix)"
export BINDIR="${PREFIX}/bin"
export SYSDIR=${PREFIX}/share/applications/kde
$ASK "This will install $UNAME (${VERSION}) system wide\n Are you sure you want to continue?"
YN=$?

if [ "$YN" != "0" ]
	then $MSG "Aborting install"
fi

if [ "$(id -u)" = "0" ]
	then export ROOTCMD=""
	else export ROOTCMD="kdesu -c"
fi

if [ ! -f $NAME ]
	then $ERROR "Please run this script from the directory with \"${NAME}\" in it"
	exit 1
fi
$ROOTCMD cp $NAME $BINDIR
desktop_file > $TEMPFILE
$ROOTCMD mv $TEMPFILE ${SYSDIR}/${NAME}.desktop
if [ ! -d ${PREFIX}/share/apps/konqueror/servicemenus/ ]
	then $ROOTCMD mkdir -p ${PREFIX}/share/apps/konqueror/servicemenus/
fi
$ROOTCMD cp mountserv.desktop ${PREFIX}/share/apps/konqueror/servicemenus/

if [ ! -d ${PREFIX}/share/apps/dolphin/servicemenus/ ]
	then $ROOTCMD mkdir -p ${PREFIX}/share/apps/dolphin/servicemenus/
fi

if [ ! -d ${PREFIX}/share/apps/d3lphin/servicemenus/ ]
	then $ROOTCMD mkdir -p ${PREFIX}/share/apps/d3lphin/servicemenus/
fi

$ROOTCMD cp mountserv.desktop ${PREFIX}/share/apps/dolphin/servicemenus/
$ROOTCMD cp mountserv.desktop ${PREFIX}/share/apps/d3lphin/servicemenus/

}

# Install for current user
user_install()
{
export PREFIX="${HOME}/.kde"
export BINDIR="${HOME}/bin"
export SYSDIR="${PREFIX}/share/applnk/Utilities/"
$ASK "This will install $UNAME (${VERSION}) for the current user (${USER})\nAre you sure you want to continue?"
YN=$?

if [ "$YN" != "0" ]
	then $MSG "Aborting install"
fi

if [ ! -d $BINDIR ]
	then mkdir -p $BINDIR ; ER=$?
	if [ "$ER" != "0" ]
		then $ERROR "Can't create $BINDIR"
		exit 1
	fi
fi

if [ ! -f $NAME ]
	then $ERROR "Please run this script from the directory with \"${NAME}\" in it"
	exit 1
fi
cp $NAME $BINDIR
desktop_file > $TEMPFILE
mkdir -p $SYSDIR
mv $TEMPFILE ${SYSDIR}/${NAME}.desktop
if [ ! -d ${PREFIX}/share/apps/konqueror/servicemenus/ ]
	then mkdir -p ${PREFIX}/share/apps/konqueror/servicemenus/
fi
cp mountserv.desktop ${PREFIX}/share/apps/konqueror/servicemenus/

if [ ! -d ${PREFIX}/share/apps/dolphin/servicemenus/ ]
	then mkdir -p ${PREFIX}/share/apps/dolphin/servicemenus/
fi
if [ ! -d ${PREFIX}/share/apps/d3lphin/servicemenus/ ]
	then mkdir -p ${PREFIX}/share/apps/d3lphin/servicemenus/
fi
cp mountserv.desktop ${PREFIX}/share/apps/dolphin/servicemenus/
cp mountserv.desktop ${PREFIX}/share/apps/d3lphin/servicemenus/

$ASK "Do you want an icon on the desktop?"
YN=$?
if [ "$YN" = "0" ]
	then cp ${SYSDIR}/${NAME}.desktop ${HOME}/Desktop/${UNAME}.desktop
fi
}

TYPE="$(kdialog --icon /usr/share/pixmaps/ark-16.xpm --caption "$UNAME installer" --radiolist "This will install $UNAME to your system.
Do you want to install for only your user or system-wide?" user "Install for user" on root "Install system-wide" off)"
NO=$?
if [ "$NO" -ne "0" ]
	then exit
fi

if [ "$TYPE" = "root" ]
	then system_install && $MSG "Done." || $ERROR "Install faild."
	else user_install && $MSG "Done." || $ERROR "Install faild."
fi
